# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.inventory.v1 import region_pb2 as spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2


class RegionStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/create',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.CreateRegionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/update',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.UpdateRegionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/delete',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/get',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.GetRegionRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/list',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.inventory.v1.Region/stat',
                request_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class RegionServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Region. As the parameter `region_key`, which is automatically created when a Region is created, is in a form of `{provider}.{region_code}`, it is unique regardless of providers. You can also specify the latitude, longitude, and continent information in `tags`.
        request_example: >-
        {
        "name": "Asia Pacific (Seoul)",
        "region_code": "ap-northeast-2",
        "provider": "aws",
        "tags": {
        "continent": "asis_pacific",
        "longitude": "73.013805",
        "latitude": "19.147428"
        }
        }
        response_example: >-
        {
        "region_id": "region-e41deed3c939",
        "name": "Asia Pacific (Seoul)",
        "region_key": "aws.ap-northeast-2",
        "region_code": "ap-northeast-2",
        "provider": "aws",
        "tags": {
        "continent": "asia_pacific",
        "longitude": "73.013805",
        "latitude": "19.147428"
        },
        "domain_id": "domain-x1b3c34v432",
        "created_at": "2021-11-18T13:07:31.382Z",
        "updated_at": "2022-06-17T00:07:35.469Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Region. You can make changes in Region settings, including `name` and `tags`. The `tags` contain the continent, latitude, and longitude.
        request_example: >-
        {
        "region_id": "region-e41deed3c939",
        "name": "Region home",
        "tags": {
        "latitude": "6.34545",
        "continent": "asia_pacific",
        "longitude": "5.6433213"
        }
        }
        response_example: >-
        {
        "region_id": "region-e41deed3c939",
        "name": "Region home",
        "region_key": "aws.ap-northeast-2",
        "region_code": "ap-northeast-2",
        "provider": "aws",
        "tags": {
        "latitude": "6.34545",
        "continent": "asia_pacific",
        "longitude": "5.6433213"
        },
        "domain_id": "domain-x1b3c34v432",
        "created_at": "2021-11-18T13:07:31.382Z",
        "updated_at": "2022-06-17T00:07:35.469Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Region. You must specify the `region_id` of the Region to delete.
        request_example: >-
        {
        "region_id": "region-e41deed3c939"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Region. Prints detailed information about the Region, including `name`, `region_code`, and a location coordinate.
        request_example: >-
        {
        "region_id": "region-f803eb00b567"
        }
        response_example: >-
        {
        "region_id": "region-f803eb00b567",
        "name": "Asia Pacific (Seoul)",
        "region_key": "aws.ap-northeast-2",
        "region_code": "ap-northeast-2",
        "provider": "aws",
        "tags": {
        "latitude": "6.34545",
        "continent": "asia_pacific",
        "longitude": "5.6433213"
        },
        "domain_id": "domain-x1b3c34v432",
        "created_at": "2022-03-21T09:08:31.961Z",
        "updated_at": "2022-06-17T00:07:35.749Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Regions. You can use a query to get a filtered list of Regions.
        request_example: >-
        {
        "query": {
        "filter": [
        {
        "key": "name",
        "value": "Asia Pacific",
        "operator": "contain"
        }
        ]
        }
        }
        response_example: >-
        {
        "results": [
        {
        "region_id": "region-e41deed3c939",
        "name": "Asia Pacific (Mumbai)",
        "region_key": "aws.ap-south-1",
        "region_code": "ap-south-1",
        "provider": "aws",
        "tags": {
        "continent": "asia_pacific",
        "longitude": "73.013805",
        "latitude": "19.147428"
        },
        "domain_id": "domain-x1b3c34v432",
        "created_at": "2021-11-18T13:07:31.382Z",
        "updated_at": "2022-06-17T00:07:35.469Z"
        },
        {
        "region_id": "region-f803eb00b567",
        "name": "Asia Pacific (Seoul)",
        "region_key": "aws.ap-northeast-2",
        "region_code": "ap-northeast-2",
        "provider": "aws",
        "tags": {
        "latitude": "6.34545",
        "continent": "asia_pacific",
        "longitude": "5.6433213"
        },
        "domain_id": "domain-x1b3c34v432",
        "created_at": "2022-03-21T09:08:31.961Z",
        "updated_at": "2022-06-17T00:07:35.749Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_RegionServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.CreateRegionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.UpdateRegionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.GetRegionRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.inventory.v1.Region', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Region(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/create',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.CreateRegionRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/update',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.UpdateRegionRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/delete',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/get',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.GetRegionRequest.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/list',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionQuery.SerializeToString,
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.inventory.v1.Region/stat',
            spaceone_dot_api_dot_inventory_dot_v1_dot_region__pb2.RegionStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.monitoring.v1 import alert_pb2 as spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2


class AlertStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/create',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.CreateAlertRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/update',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.update_state = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/update_state',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertStateRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.merge = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/merge',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.MergeAlertRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.snooze = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/snooze',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.SnoozeAlertRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.add_responder = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/add_responder',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.remove_responder = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/remove_responder',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.add_project_dependency = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/add_project_dependency',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.remove_project_dependency = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/remove_project_dependency',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/delete',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/get',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.GetAlertRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/list',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.monitoring.v1.Alert/stat',
                request_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class AlertServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Alert. Alerts generated with `create` method are made in a manual way. Manually made Alerts can be used for Notifications.
        request_example: >-
        {
        "title": "sample test",
        "description": "This is a description of sample.",
        "urgency": "HIGH",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "alert_number": 104053,
        "alert_id": "alert-123456789012",
        "title": "sample test",
        "state": "TRIGGERED",
        "description": "This is a description of sample.",
        "urgency": "HIGH",
        "severity": "NONE",
        "escalation_step": 1,
        "additional_info": {},
        "triggered_by": "user1@email.com",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T01:43:08.566Z",
        "updated_at": "2022-01-01T01:43:08.566Z",
        "escalated_at": "2022-01-01T01:43:54.464Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Alert. You can make changes in Alert settings, including the `title`, `description`, `responder`, `state`, and `urgency`. The `responder` of the Alert is a User who is assigned to respond to the Alert.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "state": "ACKNOWLEDGED",
        "urgency": "LOW",
        "description": "[updating]This is a description of sample.",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "alert_number": 104053,
        "alert_id": "alert-123456789012",
        "title": "sample test",
        "state": "ACKNOWLEDGED",
        "description": "[updating]This is a description of sample. ",
        "urgency": "LOW",
        "severity": "NONE",
        "escalation_step": 1,
        "additional_info": {},
        "triggered_by": "user1@email.com",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T01:43:08.566Z",
        "updated_at": "2022-01-01T01:43:08.566Z",
        "acknowledged_at": "2022-01-01T01:48:52.799Z",
        "escalated_at": "2022-01-01T01:43:54.464Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_state(self, request, context):
        """
        desc: Updates the state of an Alert via callback URL by creating a temporary `access_key` while generating a Notification about the Alert.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "access_key": "1q2w3e4r5t6y7u8i9o0p",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def merge(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def snooze(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_responder(self, request, context):
        """
        desc: Adds a responder who receives a Notification about an Alert.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "resource_type": "identity.User",
        "resource_id": "user2@email.com",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "alert_number": 104053,
        "alert_id": "alert-123456789012",
        "title": "sample test",
        "state": "ACKNOWLEDGED",
        "description": "[updating]This is a description of sample. ",
        "urgency": "LOW",
        "severity": "NONE",
        "escalation_step": 1,
        "responders": [
        {
        "resource_type": "identity.User",
        "resource_id": "user2@email.com"
        }
        ],
        "additional_info": {},
        "triggered_by": "user1@email.com",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T01:43:08.566Z",
        "updated_at": "2022-01-01T01:43:08.566Z",
        "acknowledged_at": "2022-01-01T02:24:12.051Z",
        "escalated_at": "2022-01-01T01:43:54.464Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove_responder(self, request, context):
        """
        desc: Deletes a responder who receives a Notification about an Alert.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "resource_type": "identity.User",
        "resource_id": "user2@email.com",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "alert_number": 104053,
        "alert_id": "alert-123456789012",
        "title": "sample test",
        "state": "ACKNOWLEDGED",
        "description": "[updating]This is a description of sample. ",
        "urgency": "LOW",
        "severity": "NONE",
        "escalation_step": 1,
        "additional_info": {},
        "triggered_by": "user1@email.com",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T01:43:08.566Z",
        "updated_at": "2022-01-01T01:43:08.566Z",
        "acknowledged_at": "2022-01-01T01:48:52.799Z",
        "escalated_at": "2022-01-01T01:43:54.464Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def add_project_dependency(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def remove_project_dependency(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Alert and remove it from the list of Alerts. You must specify the `alert_id` of the Alert to delete.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Alert. Prints detailed information about the Alert.
        request_example: >-
        {
        "alert_id": "alert-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "alert_number": 104053,
        "alert_id": "alert-123456789012",
        "title": "sample test",
        "state": "ACKNOWLEDGED",
        "description": "[updating]This is a description of sample. ",
        "urgency": "LOW",
        "severity": "NONE",
        "escalation_step": 1,
        "additional_info": {},
        "triggered_by": "user1@email.com",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T01:43:08.566Z",
        "updated_at": "2022-01-01T01:43:08.566Z",
        "acknowledged_at": "2022-01-01T01:48:52.799Z",
        "escalated_at": "2022-01-01T01:43:54.464Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Alerts. You can use a query to get a filtered list of Alerts.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "alert_number": 104057,
        "alert_id": "alert-987654321098",
        "title": "Notification of access to the bastion Host",
        "state": "TRIGGERED",
        "description": "SSH Access to stargate-dev from adm",
        "urgency": "LOW",
        "severity": "INFO",
        "resource": {
        "resource_id": "server-123456789012",
        "resource_type": "inventory.Server",
        "name": "stargate-dev"
        },
        "escalation_step": 1,
        "escalation_ttl": 1,
        "additional_info": {
        "host": "[]",
        "user": "user1"
        },
        "triggered_by": "webhook-123456789012",
        "webhook_id": "webhook-123456789012",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T02:46:35.934Z",
        "updated_at": "2022-01-01T02:46:35.934Z",
        "escalated_at": "2022-01-01T02:46:35.979Z"
        },
        {
        "alert_number": 104056,
        "alert_id": "alert-123456789999",
        "title": "Notification of access to the bastion Host",
        "state": "TRIGGERED",
        "description": "SSH Access to stargate-dev from user3@email.com",
        "urgency": "LOW",
        "severity": "INFO",
        "resource": {
        "resource_id": "server-123456789012",
        "resource_type": "inventory.Server",
        "name": "stargate-dev"
        },
        "escalation_step": 1,
        "escalation_ttl": 1,
        "additional_info": {
        "user": "user3@email.com",
        "host": "['111.111.111.11']"
        },
        "triggered_by": "webhook-123456789012",
        "webhook_id": "webhook-123456789012",
        "escalation_policy_id": "ep-123456789012",
        "project_id": "project-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T02:46:31.391Z",
        "updated_at": "2022-01-01T02:46:31.391Z",
        "escalated_at": "2022-01-01T02:46:31.553Z"
        }
        ],
        "total_count": 21283
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_AlertServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.CreateAlertRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'update_state': grpc.unary_unary_rpc_method_handler(
                    servicer.update_state,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertStateRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'merge': grpc.unary_unary_rpc_method_handler(
                    servicer.merge,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.MergeAlertRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'snooze': grpc.unary_unary_rpc_method_handler(
                    servicer.snooze,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.SnoozeAlertRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'add_responder': grpc.unary_unary_rpc_method_handler(
                    servicer.add_responder,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'remove_responder': grpc.unary_unary_rpc_method_handler(
                    servicer.remove_responder,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'add_project_dependency': grpc.unary_unary_rpc_method_handler(
                    servicer.add_project_dependency,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'remove_project_dependency': grpc.unary_unary_rpc_method_handler(
                    servicer.remove_project_dependency,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.GetAlertRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.monitoring.v1.Alert', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Alert(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/create',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.CreateAlertRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/update',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_state(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/update_state',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.UpdateAlertStateRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def merge(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/merge',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.MergeAlertRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def snooze(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/snooze',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.SnoozeAlertRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_responder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/add_responder',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def remove_responder(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/remove_responder',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertResponderRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def add_project_dependency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/add_project_dependency',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def remove_project_dependency(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/remove_project_dependency',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertProjectDependencyRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/delete',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/get',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.GetAlertRequest.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/list',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertQuery.SerializeToString,
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.monitoring.v1.Alert/stat',
            spaceone_dot_api_dot_monitoring_dot_v1_dot_alert__pb2.AlertStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/plugin/v1/plugin.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#spaceone/api/plugin/v1/plugin.proto\x12\x16spaceone.api.plugin.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\"\xed\x01\n\x15PluginEndpointRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\'\n\x06labels\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x04 \x01(\t\x12O\n\x0cupgrade_mode\x18\x05 \x01(\x0e\x32\x39.spaceone.api.plugin.v1.PluginEndpointRequest.UpgradeMode\"#\n\x0bUpgradeMode\x12\n\n\x06MANUAL\x10\x00\x12\x08\n\x04\x41UTO\x10\x01\"d\n\x14PluginFailureRequest\x12\x15\n\rsupervisor_id\x18\x01 \x01(\t\x12\x11\n\tplugin_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"Q\n\x0ePluginEndpoint\x12\x10\n\x08\x65ndpoint\x18\x01 \x01(\t\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x02 \x01(\t\x12\x17\n\x0fupdated_version\x18\x03 \x01(\t2\xba\x02\n\x06Plugin\x12\xa0\x01\n\x13get_plugin_endpoint\x12-.spaceone.api.plugin.v1.PluginEndpointRequest\x1a&.spaceone.api.plugin.v1.PluginEndpoint\"2\x82\xd3\xe4\x93\x02,\"*/plugin/v1/plugin/{plugin_id}/get-endpoint\x12\x8c\x01\n\x0enotify_failure\x12,.spaceone.api.plugin.v1.PluginFailureRequest\x1a\x16.google.protobuf.Empty\"4\x82\xd3\xe4\x93\x02.\x1a,/plugin/v1/plugin/{plugin_id}/notify-failureb\x06proto3')



_PLUGINENDPOINTREQUEST = DESCRIPTOR.message_types_by_name['PluginEndpointRequest']
_PLUGINFAILUREREQUEST = DESCRIPTOR.message_types_by_name['PluginFailureRequest']
_PLUGINENDPOINT = DESCRIPTOR.message_types_by_name['PluginEndpoint']
_PLUGINENDPOINTREQUEST_UPGRADEMODE = _PLUGINENDPOINTREQUEST.enum_types_by_name['UpgradeMode']
PluginEndpointRequest = _reflection.GeneratedProtocolMessageType('PluginEndpointRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINENDPOINTREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginEndpointRequest)
  })
_sym_db.RegisterMessage(PluginEndpointRequest)

PluginFailureRequest = _reflection.GeneratedProtocolMessageType('PluginFailureRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINFAILUREREQUEST,
  '__module__' : 'spaceone.api.plugin.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginFailureRequest)
  })
_sym_db.RegisterMessage(PluginFailureRequest)

PluginEndpoint = _reflection.GeneratedProtocolMessageType('PluginEndpoint', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINENDPOINT,
  '__module__' : 'spaceone.api.plugin.v1.plugin_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.plugin.v1.PluginEndpoint)
  })
_sym_db.RegisterMessage(PluginEndpoint)

_PLUGIN = DESCRIPTOR.services_by_name['Plugin']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PLUGIN.methods_by_name['get_plugin_endpoint']._options = None
  _PLUGIN.methods_by_name['get_plugin_endpoint']._serialized_options = b'\202\323\344\223\002,\"*/plugin/v1/plugin/{plugin_id}/get-endpoint'
  _PLUGIN.methods_by_name['notify_failure']._options = None
  _PLUGIN.methods_by_name['notify_failure']._serialized_options = b'\202\323\344\223\002.\032,/plugin/v1/plugin/{plugin_id}/notify-failure'
  _PLUGINENDPOINTREQUEST._serialized_start=153
  _PLUGINENDPOINTREQUEST._serialized_end=390
  _PLUGINENDPOINTREQUEST_UPGRADEMODE._serialized_start=355
  _PLUGINENDPOINTREQUEST_UPGRADEMODE._serialized_end=390
  _PLUGINFAILUREREQUEST._serialized_start=392
  _PLUGINFAILUREREQUEST._serialized_end=492
  _PLUGINENDPOINT._serialized_start=494
  _PLUGINENDPOINT._serialized_end=575
  _PLUGIN._serialized_start=578
  _PLUGIN._serialized_end=892
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/catalog.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from spaceone.api.provisioning.v1 import catalog_resource_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__resource__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.provisioning.v1 import catalog_group_pb2 as spaceone_dot_api_dot_provisioning_dot_v1_dot_catalog__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/provisioning/v1/catalog.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x33spaceone/api/provisioning/v1/catalog_resource.proto\x1a spaceone/api/core/v1/query.proto\x1a\x30spaceone/api/provisioning/v1/catalog_group.proto\"\xb9\x01\n\x15PublishCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x1a\n\x12service_account_id\x18\x04 \x01(\t\x12\x0e\n\x06region\x18\x05 \x01(\t\x12\x0e\n\x06status\x18\x06 \x01(\t\x12\x13\n\x0bplan_status\x18\x07 \x01(\t\x12\x14\n\x0cpublish_type\x18\x08 \x01(\t\"\x85\x03\n\x14\x43reateCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x02 \x01(\t\x12\x16\n\x0eterraform_code\x18\x03 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x06 \x01(\t\x12\x12\n\nupdated_by\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x10\n\x08provider\x18\t \x01(\t\x12\x13\n\x0bplan_status\x18\n \x01(\t\x12\x0f\n\x07opinion\x18\x0b \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\x0c \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\r \x01(\t\x12\x44\n\tresources\x18\x0e \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x0f \x01(\t\"7\n\x0e\x43\x61talogRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetCatalogRequest\x12\x12\n\ncatalog_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x99\x03\n\x14UpdateCatalogRequest\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x10\n\x08provider\x18\n \x01(\t\x12\x13\n\x0bplan_status\x18\x0b \x01(\t\x12\x0f\n\x07opinion\x18\x0c \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\r \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\x0e \x01(\t\x12\x44\n\tresources\x18\x0f \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x10 \x01(\t\"\x84\x04\n\x0b\x43\x61talogInfo\x12\x11\n\tdomain_id\x18\x01 \x01(\t\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x16\n\x0eterraform_code\x18\x04 \x01(\t\x12-\n\x0c\x64iagram_info\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x12\n\ncreated_by\x18\x07 \x01(\t\x12\x12\n\nupdated_by\x18\x08 \x01(\t\x12\x12\n\ncreated_at\x18\t \x01(\t\x12\x12\n\nupdated_at\x18\n \x01(\t\x12\x0e\n\x06status\x18\x0b \x01(\t\x12\x10\n\x08provider\x18\x0c \x01(\t\x12\x13\n\x0bplan_status\x18\r \x01(\t\x12\x0f\n\x07opinion\x18\x0e \x01(\t\x12\x17\n\x0f\x63\x61talog_summary\x18\x0f \x01(\t\x12\x14\n\x0c\x63\x61talog_desc\x18\x10 \x01(\t\x12\x44\n\tresources\x18\x11 \x03(\x0b\x32\x31.spaceone.api.provisioning.v1.CatalogResourceInfo\x12\x18\n\x10\x63\x61talog_group_id\x18\x12 \x01(\t\x12J\n\x12\x63\x61talog_group_info\x18\x13 \x01(\x0b\x32..spaceone.api.provisioning.v1.CatalogGroupInfo\"_\n\x0c\x43\x61talogsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.provisioning.v1.CatalogInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\xaf\x01\n\x0c\x43\x61talogQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\ncatalog_id\x18\x02 \x01(\t\x12\x14\n\x0c\x63\x61talog_name\x18\x03 \x01(\t\x12\x12\n\ncreated_by\x18\x04 \x01(\t\x12\x12\n\nupdated_by\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\x12\x0e\n\x06status\x18\x07 \x01(\t\"[\n\x10\x43\x61talogStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb6\n\n\x07\x43\x61talog\x12\x91\x01\n\x0e\x63reate_catalog\x12\x32.spaceone.api.provisioning.v1.CreateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\" \x82\xd3\xe4\x93\x02\x1a\"\x18/provisioning/v1/catalog\x12\xad\x01\n\x0cget_catalogs\x12*.spaceone.api.provisioning.v1.CatalogQuery\x1a*.spaceone.api.provisioning.v1.CatalogsInfo\"E\x82\xd3\xe4\x93\x02?\x12\x19/provisioning/v1/catalogsZ\"\" /provisioning/v1/catalogs/search\x12\x98\x01\n\x0bget_catalog\x12/.spaceone.api.provisioning.v1.GetCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\"-\x82\xd3\xe4\x93\x02\'\x12%/provisioning/v1/catalog/{catalog_id}\x12\x91\x01\n\x0eupdate_catalog\x12\x32.spaceone.api.provisioning.v1.UpdateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\" \x82\xd3\xe4\x93\x02\x1a\x1a\x18/provisioning/v1/catalog\x12\x85\x01\n\x0e\x64\x65lete_catalog\x12,.spaceone.api.provisioning.v1.CatalogRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/provisioning/v1/catalog/{catalog_id}\x12\x88\x01\n\x0fpublish_catalog\x12\x33.spaceone.api.provisioning.v1.PublishCatalogRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /provisioning/v1/catalog/publish\x12v\n\x04stat\x12..spaceone.api.provisioning.v1.CatalogStatQuery\x1a\x17.google.protobuf.Struct\"%\x82\xd3\xe4\x93\x02\x1f\"\x1d/provisioning/v1/catalog/stat\x12\x85\x01\n\x0cplan_catalog\x12\x33.spaceone.api.provisioning.v1.PublishCatalogRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\" /provisioning/v1/catalog/publish\x12\xa4\x01\n\x10\x61pproval_process\x12\x32.spaceone.api.provisioning.v1.UpdateCatalogRequest\x1a).spaceone.api.provisioning.v1.CatalogInfo\"1\x82\xd3\xe4\x93\x02+\x1a)/provisioning/v1/catalog/approval-processb\x06proto3')



_PUBLISHCATALOGREQUEST = DESCRIPTOR.message_types_by_name['PublishCatalogRequest']
_CREATECATALOGREQUEST = DESCRIPTOR.message_types_by_name['CreateCatalogRequest']
_CATALOGREQUEST = DESCRIPTOR.message_types_by_name['CatalogRequest']
_GETCATALOGREQUEST = DESCRIPTOR.message_types_by_name['GetCatalogRequest']
_UPDATECATALOGREQUEST = DESCRIPTOR.message_types_by_name['UpdateCatalogRequest']
_CATALOGINFO = DESCRIPTOR.message_types_by_name['CatalogInfo']
_CATALOGSINFO = DESCRIPTOR.message_types_by_name['CatalogsInfo']
_CATALOGQUERY = DESCRIPTOR.message_types_by_name['CatalogQuery']
_CATALOGSTATQUERY = DESCRIPTOR.message_types_by_name['CatalogStatQuery']
PublishCatalogRequest = _reflection.GeneratedProtocolMessageType('PublishCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _PUBLISHCATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.PublishCatalogRequest)
  })
_sym_db.RegisterMessage(PublishCatalogRequest)

CreateCatalogRequest = _reflection.GeneratedProtocolMessageType('CreateCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CreateCatalogRequest)
  })
_sym_db.RegisterMessage(CreateCatalogRequest)

CatalogRequest = _reflection.GeneratedProtocolMessageType('CatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogRequest)
  })
_sym_db.RegisterMessage(CatalogRequest)

GetCatalogRequest = _reflection.GeneratedProtocolMessageType('GetCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.GetCatalogRequest)
  })
_sym_db.RegisterMessage(GetCatalogRequest)

UpdateCatalogRequest = _reflection.GeneratedProtocolMessageType('UpdateCatalogRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECATALOGREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.UpdateCatalogRequest)
  })
_sym_db.RegisterMessage(UpdateCatalogRequest)

CatalogInfo = _reflection.GeneratedProtocolMessageType('CatalogInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogInfo)
  })
_sym_db.RegisterMessage(CatalogInfo)

CatalogsInfo = _reflection.GeneratedProtocolMessageType('CatalogsInfo', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGSINFO,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogsInfo)
  })
_sym_db.RegisterMessage(CatalogsInfo)

CatalogQuery = _reflection.GeneratedProtocolMessageType('CatalogQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogQuery)
  })
_sym_db.RegisterMessage(CatalogQuery)

CatalogStatQuery = _reflection.GeneratedProtocolMessageType('CatalogStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CATALOGSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.catalog_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.CatalogStatQuery)
  })
_sym_db.RegisterMessage(CatalogStatQuery)

_CATALOG = DESCRIPTOR.services_by_name['Catalog']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CATALOG.methods_by_name['create_catalog']._options = None
  _CATALOG.methods_by_name['create_catalog']._serialized_options = b'\202\323\344\223\002\032\"\030/provisioning/v1/catalog'
  _CATALOG.methods_by_name['get_catalogs']._options = None
  _CATALOG.methods_by_name['get_catalogs']._serialized_options = b'\202\323\344\223\002?\022\031/provisioning/v1/catalogsZ\"\" /provisioning/v1/catalogs/search'
  _CATALOG.methods_by_name['get_catalog']._options = None
  _CATALOG.methods_by_name['get_catalog']._serialized_options = b'\202\323\344\223\002\'\022%/provisioning/v1/catalog/{catalog_id}'
  _CATALOG.methods_by_name['update_catalog']._options = None
  _CATALOG.methods_by_name['update_catalog']._serialized_options = b'\202\323\344\223\002\032\032\030/provisioning/v1/catalog'
  _CATALOG.methods_by_name['delete_catalog']._options = None
  _CATALOG.methods_by_name['delete_catalog']._serialized_options = b'\202\323\344\223\002\'*%/provisioning/v1/catalog/{catalog_id}'
  _CATALOG.methods_by_name['publish_catalog']._options = None
  _CATALOG.methods_by_name['publish_catalog']._serialized_options = b'\202\323\344\223\002\"\" /provisioning/v1/catalog/publish'
  _CATALOG.methods_by_name['stat']._options = None
  _CATALOG.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\037\"\035/provisioning/v1/catalog/stat'
  _CATALOG.methods_by_name['plan_catalog']._options = None
  _CATALOG.methods_by_name['plan_catalog']._serialized_options = b'\202\323\344\223\002\"\" /provisioning/v1/catalog/publish'
  _CATALOG.methods_by_name['approval_process']._options = None
  _CATALOG.methods_by_name['approval_process']._serialized_options = b'\202\323\344\223\002+\032)/provisioning/v1/catalog/approval-process'
  _PUBLISHCATALOGREQUEST._serialized_start=303
  _PUBLISHCATALOGREQUEST._serialized_end=488
  _CREATECATALOGREQUEST._serialized_start=491
  _CREATECATALOGREQUEST._serialized_end=880
  _CATALOGREQUEST._serialized_start=882
  _CATALOGREQUEST._serialized_end=937
  _GETCATALOGREQUEST._serialized_start=939
  _GETCATALOGREQUEST._serialized_end=1011
  _UPDATECATALOGREQUEST._serialized_start=1014
  _UPDATECATALOGREQUEST._serialized_end=1423
  _CATALOGINFO._serialized_start=1426
  _CATALOGINFO._serialized_end=1942
  _CATALOGSINFO._serialized_start=1944
  _CATALOGSINFO._serialized_end=2039
  _CATALOGQUERY._serialized_start=2042
  _CATALOGQUERY._serialized_end=2217
  _CATALOGSTATQUERY._serialized_start=2219
  _CATALOGSTATQUERY._serialized_end=2310
  _CATALOG._serialized_start=2313
  _CATALOG._serialized_end=3647
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.secret.v1 import trusted_secret_pb2 as spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2


class TrustedSecretStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/create',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.CreateTrustedSecretRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/update',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/delete',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.update_data = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/update_data',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretDataRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/get',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.GetTrustedSecretRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/list',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.secret.v1.TrustedSecret/stat',
                request_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class TrustedSecretServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new Trusted Secret. When creating the resource, external `data` is encrypted, and a `trusted_secret_id` is issued for data access by other microservices.
        request_example: >-
        {
        "name": "aws-dev",
        "data": "********",
        "schema": "aws_access_key",
        "service_account_id": "sa-123456789012",
        "tags": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "name": "aws-dev",
        "tags": {},
        "schema": "aws_access_key",
        "provider": "aws",
        "service_account_id": "sa-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:10:14.851Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Secret. You can make changes in Secret settings, including `name` and`tags`.
        request_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "name": "aws-dev2",
        "tags": { "a": "b"},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "name": "aws-dev2",
        "tags": { "a": "b"},
        "schema": "aws_access_key",
        "provider": "aws",
        "service_account_id": "sa-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:10:14.851Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific Secret. You must specify the `secret_id` of the Secret to delete.
        request_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "domain_id": "domain-123456789012"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update_data(self, request, context):
        """
        desc: Updates encrypted data of a specific Secret resource. For example, to change the parameter `data`, external data to encrypt, you can use `update_data` to create new encrypted data based on the changed `data` and store it in the Secret resource.
        request_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "data": "********",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "data": {
        "encrypted_data": "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx"
        },
        "encrypted": true,
        "encrypt_options": {
        "encrypted_data_key": "xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx",
        "encrypt_algorithm": "CloudForet_DEFAULT"
        }
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Post. You must specify the `post_id` of the Post to get, and the `board_id` of the Board where the child Post to get belongs. Prints detailed information about the Post.
        request_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "name": "aws-dev",
        "tags": {},
        "schema": "aws_access_key",
        "provider": "aws",
        "service_account_id": "sa-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:10:14.851Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Posts. You can use a query to get a filtered list of Posts.
        request_example: >-
        {
        "query": {},
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "trusted_secret_id": "trusted-secret-123456789012",
        "name": "aws-dev",
        "tags": {},
        "schema": "aws_access_key",
        "provider": "aws",
        "service_account_id": "sa-123456789012",
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T06:10:14.851Z"
        },
        {
        "trusted_secret_id": "trusted-secret-987654321098",
        "name": "plugin-credentials",
        "tags": {},
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T02:31:01.709Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_TrustedSecretServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.CreateTrustedSecretRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'update_data': grpc.unary_unary_rpc_method_handler(
                    servicer.update_data,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretDataRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.GetTrustedSecretRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.secret.v1.TrustedSecret', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class TrustedSecret(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/create',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.CreateTrustedSecretRequest.SerializeToString,
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/update',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretRequest.SerializeToString,
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/delete',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update_data(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/update_data',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.UpdateTrustedSecretDataRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/get',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.GetTrustedSecretRequest.SerializeToString,
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/list',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretQuery.SerializeToString,
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.secret.v1.TrustedSecret/stat',
            spaceone_dot_api_dot_secret_dot_v1_dot_trusted__secret__pb2.TrustedSecretStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/dashboard/v1/project_dashboard.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1spaceone/api/dashboard/v1/project_dashboard.proto\x12\x19spaceone.api.dashboard.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\",\n\x19ProjectDashboardDateRange\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"+\n\x18ProjectDashboardCurrency\x12\x0f\n\x07\x65nabled\x18\x01 \x01(\x08\"\xab\x01\n\x18ProjectDashboardSettings\x12H\n\ndate_range\x18\x01 \x01(\x0b\x32\x34.spaceone.api.dashboard.v1.ProjectDashboardDateRange\x12\x45\n\x08\x63urrency\x18\x02 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardCurrency\"\x93\x04\n\x1d\x43reateProjectDashboardRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12Q\n\x07viewers\x18\x03 \x01(\x0e\x32@.spaceone.api.dashboard.v1.CreateProjectDashboardRequest.Viewers\x12+\n\x07layouts\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x06 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\x94\x03\n\x1dUpdateProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12+\n\x07layouts\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x06 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"J\n\x17ProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"[\n\x1aGetProjectDashboardRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"b\n\x1eProjectDashboardVersionRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"s\n!GetProjectDashboardVersionRequest\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\x12\x0c\n\x04only\x18\x0b \x03(\t\"\x8c\x01\n\x1cProjectDashboardVersionQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1c\n\x14project_dashboard_id\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xa8\x02\n\x15ProjectDashboardQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1c\n\x14project_dashboard_id\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12I\n\x07viewers\x18\x05 \x01(\x0e\x32\x38.spaceone.api.dashboard.v1.ProjectDashboardQuery.Viewers\x12\x0f\n\x07user_id\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"\xe9\x04\n\x14ProjectDashboardInfo\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12H\n\x07viewers\x18\x04 \x01(\x0e\x32\x37.spaceone.api.dashboard.v1.ProjectDashboardInfo.Viewers\x12\x0f\n\x07version\x18\x05 \x01(\x05\x12+\n\x07layouts\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x08 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\n \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x14 \x01(\t\x12\x11\n\tdomain_id\x18\x16 \x01(\t\x12\x12\n\ncreated_at\x18\x17 \x01(\t\x12\x12\n\nupdated_at\x18\x18 \x01(\t\"4\n\x07Viewers\x12\x10\n\x0cVIEWERS_NONE\x10\x00\x12\n\n\x06PUBLIC\x10\x01\x12\x0b\n\x07PRIVATE\x10\x02\"n\n\x15ProjectDashboardsInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.dashboard.v1.ProjectDashboardInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"d\n\x19ProjectDashboardStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xe6\x02\n\x1bProjectDashboardVersionInfo\x12\x1c\n\x14project_dashboard_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0e\n\x06latest\x18\x03 \x01(\x08\x12+\n\x07layouts\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x32\n\x11\x64\x61shboard_options\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x45\n\x08settings\x18\x07 \x01(\x0b\x32\x33.spaceone.api.dashboard.v1.ProjectDashboardSettings\x12\x39\n\x18\x64\x61shboard_options_schema\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x16 \x01(\t\"|\n\x1cProjectDashboardVersionsInfo\x12G\n\x07results\x18\x01 \x03(\x0b\x32\x36.spaceone.api.dashboard.v1.ProjectDashboardVersionInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xf9\x0e\n\x10ProjectDashboard\x12\x9d\x01\n\x06\x63reate\x12\x38.spaceone.api.dashboard.v1.CreateProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\"(\x82\xd3\xe4\x93\x02\"\" /dashboard/v1/project-dashboards\x12\xb3\x01\n\x06update\x12\x38.spaceone.api.dashboard.v1.UpdateProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\">\x82\xd3\xe4\x93\x02\x38\x1a\x36/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\x94\x01\n\x06\x64\x65lete\x12\x32.spaceone.api.dashboard.v1.ProjectDashboardRequest\x1a\x16.google.protobuf.Empty\">\x82\xd3\xe4\x93\x02\x38*6/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\xad\x01\n\x03get\x12\x35.spaceone.api.dashboard.v1.GetProjectDashboardRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\">\x82\xd3\xe4\x93\x02\x38\x12\x36/dashboard/v1/project-dashboard/{project_dashboard_id}\x12\xb5\x01\n\x0e\x64\x65lete_version\x12\x39.spaceone.api.dashboard.v1.ProjectDashboardVersionRequest\x1a\x16.google.protobuf.Empty\"P\x82\xd3\xe4\x93\x02J*H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}\x12\xd5\x01\n\x0erevert_version\x12\x39.spaceone.api.dashboard.v1.ProjectDashboardVersionRequest\x1a/.spaceone.api.dashboard.v1.ProjectDashboardInfo\"W\x82\xd3\xe4\x93\x02Q\"O/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}/revert\x12\xd5\x01\n\x0bget_version\x12<.spaceone.api.dashboard.v1.GetProjectDashboardVersionRequest\x1a\x36.spaceone.api.dashboard.v1.ProjectDashboardVersionInfo\"P\x82\xd3\xe4\x93\x02J\x12H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}\x12\x96\x02\n\rlist_versions\x12\x37.spaceone.api.dashboard.v1.ProjectDashboardVersionQuery\x1a\x37.spaceone.api.dashboard.v1.ProjectDashboardVersionsInfo\"\x92\x01\x82\xd3\xe4\x93\x02\x8b\x01\x12?/dashboard/v1/project-dashboard/{project_dashboard_id}/versionsZH\"F/dashboard/v1/project-dashboard/{project_dashboard_id}/versions/search\x12\xbf\x01\n\x04list\x12\x30.spaceone.api.dashboard.v1.ProjectDashboardQuery\x1a\x30.spaceone.api.dashboard.v1.ProjectDashboardsInfo\"S\x82\xd3\xe4\x93\x02M\x12 /dashboard/v1/project-dashboardsZ)\"\'/dashboard/v1/project-dashboards/search\x12\x84\x01\n\x04stat\x12\x34.spaceone.api.dashboard.v1.ProjectDashboardStatQuery\x1a\x17.google.protobuf.Struct\"-\x82\xd3\xe4\x93\x02\'\"%/dashboard/v1/project-dashboards/statb\x06proto3')



_PROJECTDASHBOARDDATERANGE = DESCRIPTOR.message_types_by_name['ProjectDashboardDateRange']
_PROJECTDASHBOARDCURRENCY = DESCRIPTOR.message_types_by_name['ProjectDashboardCurrency']
_PROJECTDASHBOARDSETTINGS = DESCRIPTOR.message_types_by_name['ProjectDashboardSettings']
_CREATEPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['CreateProjectDashboardRequest']
_UPDATEPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['UpdateProjectDashboardRequest']
_PROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['ProjectDashboardRequest']
_GETPROJECTDASHBOARDREQUEST = DESCRIPTOR.message_types_by_name['GetProjectDashboardRequest']
_PROJECTDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionRequest']
_GETPROJECTDASHBOARDVERSIONREQUEST = DESCRIPTOR.message_types_by_name['GetProjectDashboardVersionRequest']
_PROJECTDASHBOARDVERSIONQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionQuery']
_PROJECTDASHBOARDQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardQuery']
_PROJECTDASHBOARDINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardInfo']
_PROJECTDASHBOARDSINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardsInfo']
_PROJECTDASHBOARDSTATQUERY = DESCRIPTOR.message_types_by_name['ProjectDashboardStatQuery']
_PROJECTDASHBOARDVERSIONINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionInfo']
_PROJECTDASHBOARDVERSIONSINFO = DESCRIPTOR.message_types_by_name['ProjectDashboardVersionsInfo']
_CREATEPROJECTDASHBOARDREQUEST_VIEWERS = _CREATEPROJECTDASHBOARDREQUEST.enum_types_by_name['Viewers']
_PROJECTDASHBOARDQUERY_VIEWERS = _PROJECTDASHBOARDQUERY.enum_types_by_name['Viewers']
_PROJECTDASHBOARDINFO_VIEWERS = _PROJECTDASHBOARDINFO.enum_types_by_name['Viewers']
ProjectDashboardDateRange = _reflection.GeneratedProtocolMessageType('ProjectDashboardDateRange', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDDATERANGE,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardDateRange)
  })
_sym_db.RegisterMessage(ProjectDashboardDateRange)

ProjectDashboardCurrency = _reflection.GeneratedProtocolMessageType('ProjectDashboardCurrency', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDCURRENCY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardCurrency)
  })
_sym_db.RegisterMessage(ProjectDashboardCurrency)

ProjectDashboardSettings = _reflection.GeneratedProtocolMessageType('ProjectDashboardSettings', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSETTINGS,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardSettings)
  })
_sym_db.RegisterMessage(ProjectDashboardSettings)

CreateProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('CreateProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.CreateProjectDashboardRequest)
  })
_sym_db.RegisterMessage(CreateProjectDashboardRequest)

UpdateProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('UpdateProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.UpdateProjectDashboardRequest)
  })
_sym_db.RegisterMessage(UpdateProjectDashboardRequest)

ProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('ProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardRequest)
  })
_sym_db.RegisterMessage(ProjectDashboardRequest)

GetProjectDashboardRequest = _reflection.GeneratedProtocolMessageType('GetProjectDashboardRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTDASHBOARDREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetProjectDashboardRequest)
  })
_sym_db.RegisterMessage(GetProjectDashboardRequest)

ProjectDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionRequest)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionRequest)

GetProjectDashboardVersionRequest = _reflection.GeneratedProtocolMessageType('GetProjectDashboardVersionRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETPROJECTDASHBOARDVERSIONREQUEST,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.GetProjectDashboardVersionRequest)
  })
_sym_db.RegisterMessage(GetProjectDashboardVersionRequest)

ProjectDashboardVersionQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionQuery)

ProjectDashboardQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardQuery)

ProjectDashboardInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardInfo)

ProjectDashboardsInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardsInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardsInfo)

ProjectDashboardStatQuery = _reflection.GeneratedProtocolMessageType('ProjectDashboardStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDSTATQUERY,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardStatQuery)
  })
_sym_db.RegisterMessage(ProjectDashboardStatQuery)

ProjectDashboardVersionInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionInfo)

ProjectDashboardVersionsInfo = _reflection.GeneratedProtocolMessageType('ProjectDashboardVersionsInfo', (_message.Message,), {
  'DESCRIPTOR' : _PROJECTDASHBOARDVERSIONSINFO,
  '__module__' : 'spaceone.api.dashboard.v1.project_dashboard_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.dashboard.v1.ProjectDashboardVersionsInfo)
  })
_sym_db.RegisterMessage(ProjectDashboardVersionsInfo)

_PROJECTDASHBOARD = DESCRIPTOR.services_by_name['ProjectDashboard']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PROJECTDASHBOARD.methods_by_name['create']._options = None
  _PROJECTDASHBOARD.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\"\" /dashboard/v1/project-dashboards'
  _PROJECTDASHBOARD.methods_by_name['update']._options = None
  _PROJECTDASHBOARD.methods_by_name['update']._serialized_options = b'\202\323\344\223\0028\0326/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['delete']._options = None
  _PROJECTDASHBOARD.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0028*6/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['get']._options = None
  _PROJECTDASHBOARD.methods_by_name['get']._serialized_options = b'\202\323\344\223\0028\0226/dashboard/v1/project-dashboard/{project_dashboard_id}'
  _PROJECTDASHBOARD.methods_by_name['delete_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['delete_version']._serialized_options = b'\202\323\344\223\002J*H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}'
  _PROJECTDASHBOARD.methods_by_name['revert_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['revert_version']._serialized_options = b'\202\323\344\223\002Q\"O/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}/revert'
  _PROJECTDASHBOARD.methods_by_name['get_version']._options = None
  _PROJECTDASHBOARD.methods_by_name['get_version']._serialized_options = b'\202\323\344\223\002J\022H/dashboard/v1/project-dashboard/{project_dashboard_id}/version/{version}'
  _PROJECTDASHBOARD.methods_by_name['list_versions']._options = None
  _PROJECTDASHBOARD.methods_by_name['list_versions']._serialized_options = b'\202\323\344\223\002\213\001\022?/dashboard/v1/project-dashboard/{project_dashboard_id}/versionsZH\"F/dashboard/v1/project-dashboard/{project_dashboard_id}/versions/search'
  _PROJECTDASHBOARD.methods_by_name['list']._options = None
  _PROJECTDASHBOARD.methods_by_name['list']._serialized_options = b'\202\323\344\223\002M\022 /dashboard/v1/project-dashboardsZ)\"\'/dashboard/v1/project-dashboards/search'
  _PROJECTDASHBOARD.methods_by_name['stat']._options = None
  _PROJECTDASHBOARD.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\'\"%/dashboard/v1/project-dashboards/stat'
  _PROJECTDASHBOARDDATERANGE._serialized_start=203
  _PROJECTDASHBOARDDATERANGE._serialized_end=247
  _PROJECTDASHBOARDCURRENCY._serialized_start=249
  _PROJECTDASHBOARDCURRENCY._serialized_end=292
  _PROJECTDASHBOARDSETTINGS._serialized_start=295
  _PROJECTDASHBOARDSETTINGS._serialized_end=466
  _CREATEPROJECTDASHBOARDREQUEST._serialized_start=469
  _CREATEPROJECTDASHBOARDREQUEST._serialized_end=1000
  _CREATEPROJECTDASHBOARDREQUEST_VIEWERS._serialized_start=948
  _CREATEPROJECTDASHBOARDREQUEST_VIEWERS._serialized_end=1000
  _UPDATEPROJECTDASHBOARDREQUEST._serialized_start=1003
  _UPDATEPROJECTDASHBOARDREQUEST._serialized_end=1407
  _PROJECTDASHBOARDREQUEST._serialized_start=1409
  _PROJECTDASHBOARDREQUEST._serialized_end=1483
  _GETPROJECTDASHBOARDREQUEST._serialized_start=1485
  _GETPROJECTDASHBOARDREQUEST._serialized_end=1576
  _PROJECTDASHBOARDVERSIONREQUEST._serialized_start=1578
  _PROJECTDASHBOARDVERSIONREQUEST._serialized_end=1676
  _GETPROJECTDASHBOARDVERSIONREQUEST._serialized_start=1678
  _GETPROJECTDASHBOARDVERSIONREQUEST._serialized_end=1793
  _PROJECTDASHBOARDVERSIONQUERY._serialized_start=1796
  _PROJECTDASHBOARDVERSIONQUERY._serialized_end=1936
  _PROJECTDASHBOARDQUERY._serialized_start=1939
  _PROJECTDASHBOARDQUERY._serialized_end=2235
  _PROJECTDASHBOARDQUERY_VIEWERS._serialized_start=948
  _PROJECTDASHBOARDQUERY_VIEWERS._serialized_end=1000
  _PROJECTDASHBOARDINFO._serialized_start=2238
  _PROJECTDASHBOARDINFO._serialized_end=2855
  _PROJECTDASHBOARDINFO_VIEWERS._serialized_start=948
  _PROJECTDASHBOARDINFO_VIEWERS._serialized_end=1000
  _PROJECTDASHBOARDSINFO._serialized_start=2857
  _PROJECTDASHBOARDSINFO._serialized_end=2967
  _PROJECTDASHBOARDSTATQUERY._serialized_start=2969
  _PROJECTDASHBOARDSTATQUERY._serialized_end=3069
  _PROJECTDASHBOARDVERSIONINFO._serialized_start=3072
  _PROJECTDASHBOARDVERSIONINFO._serialized_end=3430
  _PROJECTDASHBOARDVERSIONSINFO._serialized_start=3432
  _PROJECTDASHBOARDVERSIONSINFO._serialized_end=3556
  _PROJECTDASHBOARD._serialized_start=3559
  _PROJECTDASHBOARD._serialized_end=5472
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/v1/metric.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'spaceone/api/monitoring/v1/metric.proto\x12\x1aspaceone.api.monitoring.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\"M\n\rMetricRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12\x11\n\tresources\x18\x02 \x03(\t\x12\x11\n\tdomain_id\x18\n \x01(\t\"\xb7\x01\n\x11MetricDataRequest\x12\x16\n\x0e\x64\x61ta_source_id\x18\x01 \x01(\t\x12-\n\x0cmetric_query\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06metric\x18\x03 \x01(\t\x12\r\n\x05start\x18\n \x01(\t\x12\x0b\n\x03\x65nd\x18\x0b \x01(\t\x12\x0e\n\x06period\x18\x0c \x01(\x05\x12\x0c\n\x04stat\x18\r \x01(\t\x12\x11\n\tdomain_id\x18\x14 \x01(\t\"\x8c\x01\n\nMetricInfo\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12%\n\x04unit\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12-\n\x0cmetric_query\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\x8f\x01\n\x0bMetricsInfo\x12\x37\n\x07metrics\x18\x01 \x03(\x0b\x32&.spaceone.api.monitoring.v1.MetricInfo\x12\x34\n\x13\x61vailable_resources\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t\"x\n\x0eMetricDataInfo\x12*\n\x06labels\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\'\n\x06values\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x03 \x01(\t2\xcb\x02\n\x06Metric\x12\x97\x01\n\x04list\x12).spaceone.api.monitoring.v1.MetricRequest\x1a\'.spaceone.api.monitoring.v1.MetricsInfo\";\x82\xd3\xe4\x93\x02\x35\x12\x33/monitoring/v1/data-source/{data_source_id}/metrics\x12\xa6\x01\n\x08get_data\x12-.spaceone.api.monitoring.v1.MetricDataRequest\x1a*.spaceone.api.monitoring.v1.MetricDataInfo\"?\x82\xd3\xe4\x93\x02\x39\x12\x37/monitoring/v1/data-source/{data_source_id}/metric-datab\x06proto3')



_METRICREQUEST = DESCRIPTOR.message_types_by_name['MetricRequest']
_METRICDATAREQUEST = DESCRIPTOR.message_types_by_name['MetricDataRequest']
_METRICINFO = DESCRIPTOR.message_types_by_name['MetricInfo']
_METRICSINFO = DESCRIPTOR.message_types_by_name['MetricsInfo']
_METRICDATAINFO = DESCRIPTOR.message_types_by_name['MetricDataInfo']
MetricRequest = _reflection.GeneratedProtocolMessageType('MetricRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricRequest)
  })
_sym_db.RegisterMessage(MetricRequest)

MetricDataRequest = _reflection.GeneratedProtocolMessageType('MetricDataRequest', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAREQUEST,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricDataRequest)
  })
_sym_db.RegisterMessage(MetricDataRequest)

MetricInfo = _reflection.GeneratedProtocolMessageType('MetricInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricInfo)
  })
_sym_db.RegisterMessage(MetricInfo)

MetricsInfo = _reflection.GeneratedProtocolMessageType('MetricsInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICSINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricsInfo)
  })
_sym_db.RegisterMessage(MetricsInfo)

MetricDataInfo = _reflection.GeneratedProtocolMessageType('MetricDataInfo', (_message.Message,), {
  'DESCRIPTOR' : _METRICDATAINFO,
  '__module__' : 'spaceone.api.monitoring.v1.metric_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.v1.MetricDataInfo)
  })
_sym_db.RegisterMessage(MetricDataInfo)

_METRIC = DESCRIPTOR.services_by_name['Metric']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _METRIC.methods_by_name['list']._options = None
  _METRIC.methods_by_name['list']._serialized_options = b'\202\323\344\223\0025\0223/monitoring/v1/data-source/{data_source_id}/metrics'
  _METRIC.methods_by_name['get_data']._options = None
  _METRIC.methods_by_name['get_data']._serialized_options = b'\202\323\344\223\0029\0227/monitoring/v1/data-source/{data_source_id}/metric-data'
  _METRICREQUEST._serialized_start=131
  _METRICREQUEST._serialized_end=208
  _METRICDATAREQUEST._serialized_start=211
  _METRICDATAREQUEST._serialized_end=394
  _METRICINFO._serialized_start=397
  _METRICINFO._serialized_end=537
  _METRICSINFO._serialized_start=540
  _METRICSINFO._serialized_end=683
  _METRICDATAINFO._serialized_start=685
  _METRICDATAINFO._serialized_end=805
  _METRIC._serialized_start=808
  _METRIC._serialized_end=1139
# @@protoc_insertion_point(module_scope)
